@@ -1,3 +1,3 @@
 __author__ = 'johannes'
 
-from core import *
\ No newline at end of file
+from .core import *
